#[repr(u8)]pub enum Tcl {
TCL_0 = 0,
TCL_1 = 1,
}Variants
TCL_0 = 0
Time Compensation Register is locked and writes are ignored.
TCL_1 = 1
Time Compensation Register is not locked and writes complete as normal.
Implementations